package com.mortals.xhx.module.certificate.web;

import com.alibaba.fastjson.JSONObject;
import com.mortals.framework.annotation.UnAuth;
import com.mortals.framework.common.Rest;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.model.PageInfo;
import com.mortals.framework.model.Result;
import com.mortals.framework.service.IUser;
import com.mortals.framework.util.DataUtil;
import com.mortals.framework.web.BaseJsonBodyController;
import com.mortals.xhx.base.system.param.service.ParamService;
import com.mortals.xhx.common.code.YesNoEnum;
import com.mortals.xhx.common.key.ParamKey;
import com.mortals.xhx.module.certificate.model.CertificateClassifyEntity;
import com.mortals.xhx.module.certificate.pdu.PrintSettingPdu;
import com.mortals.xhx.module.certificate.service.CertificateClassifyService;
import com.mortals.xhx.module.record.model.ApplyLogEntity;
import com.mortals.xhx.module.record.model.PrintWaitQueueEntity;
import com.mortals.xhx.module.record.service.ApplyLogService;
import com.mortals.xhx.module.record.service.PrintWaitQueueService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping("print")
public class CertificatePrintController extends BaseJsonBodyController {

    @Autowired
    private ParamService paramService;
    @Autowired
    private CertificateClassifyService certificateClassifyService;
    @Autowired
    private PrintWaitQueueService printWaitQueueService;

    @PostMapping({"setting/info"})
    public Rest<Object> list() {
        IUser user = this.getCurUser();
        if(user==null){
            throw new AppException("用户未登录");
        }
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        String busiDesc = "查询打印设置信息" ;

        int code=1;
        try {
            CertificateClassifyEntity query = new CertificateClassifyEntity();
            query.setShowFront(YesNoEnum.YES.getValue());
            List<CertificateClassifyEntity> showList = certificateClassifyService.find(query);
            query.setShowFront(YesNoEnum.NO.getValue());
            List<CertificateClassifyEntity> hideList = certificateClassifyService.find(query);
            model.put("showList", showList);
            model.put("hideList", hideList);
            model.put("printMax", paramService.getParamIntValue(ParamKey.ALLOW_PRINT_MAX_COUNT));
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }

        ret.setCode(code);
        ret.setData(model);
        ret.setDict(model.get("dict"));
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }

    @PostMapping({"setting/save"})
    public Rest<Object> deptList(@RequestBody PrintSettingPdu settingPdu) {
        IUser user = this.getCurUser();
        if(user==null){
            throw new AppException("用户未登录");
        }
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        String busiDesc = "保存打印设置" ;

        int code=1;
        try {
            paramService.setValueByKey(ParamKey.ALLOW_PRINT_MAX_COUNT,DataUtil.conver2String(settingPdu.getPrintMax()));
            certificateClassifyService.setShowFront(settingPdu.getHideList(),YesNoEnum.NO.getValue());
            certificateClassifyService.setShowFront(settingPdu.getShowList(),YesNoEnum.YES.getValue());
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }

        ret.setCode(code);
        ret.setData(model);
        ret.setDict(model.get("dict"));
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }

    /**
     * 打印文件
     */
    @RequestMapping(value = {"do"},method = {RequestMethod.POST, RequestMethod.GET})
    @UnAuth
    public Rest<Object> print(Long id) {
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        String busiDesc = "打印证件";
        int code=1;
        try {
            String rsp = printWaitQueueService.doPrint(id);
            JSONObject jsonObject = JSONObject.parseObject(rsp);
            if(jsonObject.getString("status").equals("1")){
                model.put("message_info", busiDesc + "成功");
            }else {
                code = -1;
                model.put("message_info", jsonObject.getString("message"));
            }
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }
        ret.setCode(code);
        ret.setData(model);
        ret.setDict(model.get("dict"));
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }

    /**
     * 获取打印文件
     */
    @RequestMapping(value = {"list"},method = {RequestMethod.POST, RequestMethod.GET})
    @UnAuth
    public Rest<Object> listByIDCard(String idCard) {
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        String busiDesc = "查询待打印证件";
        int code=1;
        try {
            PrintWaitQueueEntity query = new PrintWaitQueueEntity();
            query.setPrintStatus(YesNoEnum.NO.getValue());
            query.setPickerIDCardNo(idCard);
            List<PrintWaitQueueEntity> list = printWaitQueueService.find(query);
            model.put("data", list);
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }
        ret.setCode(code);
        ret.setData(model);
        ret.setDict(model.get("dict"));
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }

}
