package com.mortals.xhx.module.record.service.impl;
import com.alibaba.fastjson.JSONObject;
import com.mortals.framework.util.HttpUtil;
import com.mortals.xhx.common.code.*;
import com.mortals.xhx.module.certificate.model.CertificateCatalogEntity;
import com.mortals.xhx.module.certificate.model.CertificateClassifyEntity;
import com.mortals.xhx.module.record.dao.PrintLogDao;
import com.mortals.xhx.module.record.dao.RetainLogDao;
import com.mortals.xhx.module.record.model.ApplyLogEntity;
import com.mortals.xhx.module.record.model.PrintLogEntity;
import com.mortals.xhx.module.record.model.RetainLogEntity;
import com.mortals.xhx.module.record.service.PrintLogService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.xhx.module.record.dao.PrintWaitQueueDao;
import com.mortals.xhx.module.record.model.PrintWaitQueueEntity;
import com.mortals.xhx.module.record.service.PrintWaitQueueService;

import java.util.Date;
import java.util.HashMap;
import java.util.Map;

/**
* PrintWaitQueueService
* 证照打印记录 service实现
*
* @author zxfei
* @date 2022-10-22
*/
@Service("printWaitQueueService")
public class PrintWaitQueueServiceImpl extends AbstractCRUDServiceImpl<PrintWaitQueueDao, PrintWaitQueueEntity, Long> implements PrintWaitQueueService {

    /** 系统ip端口 */
    @Value("${system.ip:http://192.168.0.98:11075/}")
    private String ip;
    /** 打印api接口地址 */
    @Value("${print.aip:http://192.168.0.58:8037/api/print/GetHardWareInfo?GetType=78}")
    private String printApi;
    /** 打印机设备ip */
    @Value("${system.print:192.168.0.11}")
    private String printIp;

    @Autowired
    private PrintLogDao printLogDao;
    @Autowired
    private RetainLogDao retainLogDao;


    @Override
    public void creatWaitQueueByApply(ApplyLogEntity applyLogEntity, int generateType, Context context) throws AppException {
        //CertificateCatalogEntity catalogEntity = certificateCatalogService.get(applyLogEntity.getCatalogId());
        if(generateType== GenerateStatus.ALL.getValue()){
            PrintWaitQueueEntity original = creatWaitQueue(applyLogEntity,GenerateStatus.ORIGINAL.getValue());
            dao.insert(original);
            PrintWaitQueueEntity duplicate = creatWaitQueue(applyLogEntity,GenerateStatus.DUPLICATE.getValue());
            dao.insert(duplicate);
        }else {
            PrintWaitQueueEntity printWaitQueueEntity = creatWaitQueue(applyLogEntity,generateType);
            dao.insert(printWaitQueueEntity);
        }
    }

    private PrintWaitQueueEntity creatWaitQueue(ApplyLogEntity applyLogEntity,int generateType){
        PrintWaitQueueEntity waitQueueEntity = new PrintWaitQueueEntity();
        waitQueueEntity.setApplyId(applyLogEntity.getId());
        waitQueueEntity.setCatalogId(applyLogEntity.getCatalogId());
        waitQueueEntity.setCatalogCode(applyLogEntity.getCatalogCode());
        waitQueueEntity.setCertificateName(applyLogEntity.getCertificateName());
        waitQueueEntity.setCertificateCode(applyLogEntity.getCertificateCode());
        waitQueueEntity.setEnterpriseName(applyLogEntity.getEnterpriseName());
        waitQueueEntity.setHolderName(applyLogEntity.getHolderName());
        waitQueueEntity.setHolderIDCardNo(applyLogEntity.getHolderIDCardNo());
        waitQueueEntity.setPickerName(applyLogEntity.getPickerName());
        waitQueueEntity.setPickerIDCardNo(applyLogEntity.getPickerIDCardNo());
        if(generateType== GenerateStatus.DUPLICATE.getValue()) {
            waitQueueEntity.setCertificateType(CertificateType.DUPLICATE.getValue());
            waitQueueEntity.setPreviewUrl(applyLogEntity.getDupPreview());
            waitQueueEntity.setCertificateUrl(applyLogEntity.getDuplicateUrl());
        }else{
            waitQueueEntity.setCertificateType(CertificateType.ORIGINAL.getValue());
            waitQueueEntity.setPreviewUrl(applyLogEntity.getOriPreview());
            waitQueueEntity.setCertificateUrl(applyLogEntity.getOriginalUrl());
        }
        waitQueueEntity.setPrintStatus(YesNoEnum.NO.getValue());
        waitQueueEntity.setCreateUserId(applyLogEntity.getCreateUserId());
        waitQueueEntity.setCreateTime(new Date());
        return waitQueueEntity;
    }

    @Override
    public String doPrint(Long id) {
        PrintWaitQueueEntity waitQueueEntity = this.dao.get(id);
        if(waitQueueEntity==null){
            throw new AppException("数据不存在或已修改");
        }
        String rootPath = this.ip.endsWith("/") ? this.ip : this.ip + "/";
        String filePath = rootPath+waitQueueEntity.getCertificateUrl();
        Map<String,String> printParameter = new HashMap<>();
        printParameter.put("printername","测试打印机");//打印机名称
        printParameter.put("printerip",printIp);//打印机网络地址
        printParameter.put("printerpapersource","1");//打印机纸盒
        printParameter.put("printerfile",filePath);//打印文件网络地址格式为doc文件或pdf文件
        try {
            //String rsp = HttpUtil.doPost(printApi, printParameter);
            String rsp = "{\n" +
                    "    \"status\": \"1\",\n" +
                    "    \"message\": \"打印成功\",\n" +
                    "  }";
            JSONObject jsonObject = JSONObject.parseObject(rsp);
            if(jsonObject.getString("status").equals("1")){
                doPrintAfter(waitQueueEntity,1);
            }else {
                doPrintAfter(waitQueueEntity,-1);
                //throw new AppException(jsonObject.getString("message"));
            }
            PrintWaitQueueEntity data = new PrintWaitQueueEntity();
            data.setId(id);
            data.setPrintStatus(YesNoEnum.YES.getValue());
            data.setUpdateTime(new Date());
            dao.update(data);
            return rsp;
        }catch (Throwable e){
            log.error("调用远程打印api接口出错",e);
            throw new AppException("调用远程打印api接口出错");
        }
    }

    private void doPrintAfter(PrintWaitQueueEntity waitQueueEntity,int printResult){
        RetainLogEntity retainLogEntity = new RetainLogEntity();
        Date now = new Date();
        retainLogEntity.setCatalogId(waitQueueEntity.getCatalogId());
        retainLogEntity.setCatalogCode(waitQueueEntity.getCatalogCode());
        retainLogEntity.setCertificateName(waitQueueEntity.getCertificateName());
        retainLogEntity.setCertificateCode(waitQueueEntity.getCertificateCode());
        retainLogEntity.setEnterpriseName(waitQueueEntity.getEnterpriseName());
        retainLogEntity.setHolderName(waitQueueEntity.getHolderName());
        retainLogEntity.setHolderIDCardNo(waitQueueEntity.getHolderIDCardNo());
        retainLogEntity.setCertificateStatus(CertificateStatus.NORMAL.getValue());
        retainLogEntity.setCreateUserId(waitQueueEntity.getCreateUserId());
        retainLogEntity.setCreateTime(now);

        PrintLogEntity printLogEntity = new PrintLogEntity();
        printLogEntity.setCatalogId(waitQueueEntity.getCatalogId());
        printLogEntity.setCatalogCode(waitQueueEntity.getCatalogCode());
        if(waitQueueEntity.getCertificateType()==CertificateType.ORIGINAL.getValue()){
            printLogEntity.setOriginalCount(1);
            printLogEntity.setDuplicateCount(0);

            retainLogEntity.setOriginalCount(1);
            retainLogEntity.setDuplicateCount(0);
            retainLogEntity.setOriginalUrl(waitQueueEntity.getCertificateUrl());
        }else {
            printLogEntity.setOriginalCount(0);
            printLogEntity.setDuplicateCount(1);

            retainLogEntity.setOriginalCount(0);
            retainLogEntity.setDuplicateCount(1);
            retainLogEntity.setDuplicateUrl(waitQueueEntity.getCertificateUrl());
        }
        printLogEntity.setCertificateName(waitQueueEntity.getCertificateName());
        printLogEntity.setCertificateCode(waitQueueEntity.getCertificateCode());
        printLogEntity.setEnterpriseName(waitQueueEntity.getEnterpriseName());
        printLogEntity.setHolderName(waitQueueEntity.getHolderName());
        printLogEntity.setHolderIDCardNo(waitQueueEntity.getHolderIDCardNo());
        printLogEntity.setPickerName(waitQueueEntity.getPickerName());
        printLogEntity.setPickerIDCardNo(waitQueueEntity.getPickerIDCardNo());

        printLogEntity.setPrintDate(now);
        printLogEntity.setCreateUserId(waitQueueEntity.getCreateUserId());
        printLogEntity.setCreateTime(now);
        if(printResult==1){
            //打印成功
            printLogEntity.setPrintStatus(PrintStatus.SUCCESS.getValue());
            retainLogDao.insert(retainLogEntity);
        }else {
            printLogEntity.setPrintStatus(PrintStatus.FAIL.getValue());
        }
        printLogDao.insert(printLogEntity);
    }
}